@@ -57,7 +57,7 @@ public:
 	typedef struct line {
 		struct line *next;
 		union {
-			char *cmd;
+			const char *cmd;
 			script::header *sub;
 		};
 		char **argv;
@@ -148,9 +148,17 @@ public:
 	public:
 		LinkedObject *scoped;	/**< scoped symbol defs */
 		LinkedObject *events;	/**< named events */
+		LinkedObject *methods;	/**< named members */
 		script::line_t *first;	/**< first line of section or define */
 		const char *name;		/**< name of script section or define */
 		unsigned resmask;		/**< post-compile processing resource mask */
+
+		/**
+		 * Used to set linked list linkage.
+		 * @param scr header to link with.
+		 */
+		inline void link(header *scr)
+			{next = scr;};
 	};
 
 	/**
@@ -202,6 +210,7 @@ public:
 		static const char *chkWhen(script *img, script::header *scr, script::line_t *line);
 		static const char *chkStrict(script *img, script::header *scr, script::line_t *line);
 		static const char *chkExpr(script *img, script::header *scr, script::line_t *line);
+		static const char *chkRef(script *ing, script::header *scr, script::line_t *line); 
 	};
 
 	/**
@@ -277,21 +286,6 @@ public:
 		 */
 		unsigned getResource(void);
 
-		/**
-		 * Get count of members in a list.
-		 * @param list to count.
-		 * @return number of members in list.
-		 */
-		unsigned listCount(const char *list);
-
-		/**
-		 * Get count of members in a list.
-		 * @param list of members to search.
-		 * @param index of member to list.
-		 * @return list member or NULL if not found.
-		 */
-		const char *listOffset(const char *list, unsigned index);
-
 	protected:
 		script::symbol *find(const char *id);
 		void skip(void);
@@ -330,6 +324,13 @@ public:
 		 * @return true if found.
 		 */		 
 		bool scriptEvent(const char *name);
+
+		/**
+	     * Search for an event object in the method table.
+		 * @param name to search for.
+		 * @retrn method if found.
+		 */
+		script::event *scriptMethod(const char *name);
 		
 		stack_t *stack;
 		pointer<script> image;
@@ -429,6 +430,7 @@ public:
 		bool scrDefine(void);
 		bool scrInvoke(void);
 		bool scrWhen(void);
+		bool scrRef(void);
 	};	
 
 	~script();
@@ -450,6 +452,17 @@ public:
 	 */
 	static script *compile(const char *filename, script *config = NULL);
 
+	/**
+	 * Compile and merge a script into an existing shared image.  This 
+	 * is related to compile, but the target script's definitions are
+	 * linked into the base config script.  Use NULL if no base.  This
+	 * is often used to compose lint images.
+	 * @param filename to merge.
+	 * @param root script to merge definitions with.
+	 * @return compiled script instance if successful.
+	 */
+	static script *merge(const char *filename, script *root = NULL);
+
 	/**
 	 * Assign new keywords from extensions and derived service.  Must
 	 * be called before any use.
@@ -497,6 +510,9 @@ public:
 	inline bool isStrict(void)
 		{return global != NULL;};
 
+	inline unsigned getLines(void)
+		{return lines;};
+
 private:
 	friend class script::strict;
 
@@ -506,6 +522,8 @@ private:
 
 	unsigned errors;
 	unsigned loop;
+	unsigned lines;
+	bool thencheck;
 	line_t **stack;
 	LinkedObject *global;
 
